@@ -3,9 +3,11 @@ Main interface for forecastquery service type definitions.
 
 Usage::
 
-    from mypy_boto3.forecastquery.type_defs import DataPointTypeDef
+    ```python
+    from mypy_boto3_forecastquery.type_defs import DataPointTypeDef
 
     data: DataPointTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
